@@ -9,7 +9,12 @@
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more 
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -17,13 +22,15 @@
 #endif
 
 #include <string.h>
+#include <stdlib.h>
 #include <gst/rtp/gstrtpbuffer.h>
+
 #include "gstrtpspeexdepay.h"
 
 /* elementfactory information */
 static const GstElementDetails gst_rtp_speexdepay_details =
-GST_ELEMENT_DETAILS ("RTP packet parser",
-    "Codec/Depayr/Network",
+GST_ELEMENT_DETAILS ("RTP packet depayloader",
+    "Codec/Depayloader/Network",
     "Extracts Speex audio from RTP packets",
     "Edgard Lima <edgard.lima@indt.org.br>");
 
@@ -45,8 +52,9 @@ GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_ALWAYS,
     GST_STATIC_CAPS ("application/x-rtp, "
         "media = (string) \"audio\", "
+        "payload = (int) " GST_RTP_PAYLOAD_DYNAMIC_STRING ", "
         "clock-rate =  (int) [6000, 48000], "
-        "encoding-name = (string) \"speex\", "
+        "encoding-name = (string) \"SPEEX\", "
         "encoding-params = (string) \"1\"")
     );
 
@@ -88,8 +96,6 @@ gst_rtp_speex_depay_class_init (GstRtpSPEEXDepayClass * klass)
   gstelement_class = (GstElementClass *) klass;
   gstbasertpdepayload_class = (GstBaseRTPDepayloadClass *) klass;
 
-  parent_class = g_type_class_peek_parent (klass);
-
   gstbasertpdepayload_class->process = gst_rtp_speex_depay_process;
   gstbasertpdepayload_class->set_caps = gst_rtp_speex_depay_setcaps;
 }
@@ -101,37 +107,104 @@ gst_rtp_speex_depay_init (GstRtpSPEEXDepay * rtpspeexdepay,
   GST_BASE_RTP_DEPAYLOAD (rtpspeexdepay)->clock_rate = 8000;
 }
 
+static gint
+gst_rtp_speex_depay_get_mode (gint rate)
+{
+  if (rate > 25000)
+    return 2;
+  else if (rate > 12500)
+    return 1;
+  else
+    return 0;
+}
+
+/* len 4 bytes LE,
+ * vendor string (len bytes),
+ * user_len 4 (0) bytes LE
+ */
+static const gchar gst_rtp_speex_comment[] =
+    "\045\0\0\0Depayloaded with GStreamer speexdepay\0\0\0\0";
+
 static gboolean
 gst_rtp_speex_depay_setcaps (GstBaseRTPDepayload * depayload, GstCaps * caps)
 {
-  GstCaps *srccaps;
-  gboolean ret;
+  GstStructure *structure;
+  GstRtpSPEEXDepay *rtpspeexdepay;
+  gint clock_rate, nb_channels;
+  GstBuffer *buf;
+  guint8 *data;
+  const gchar *params;
 
-  srccaps =
-      gst_static_pad_template_get_caps (&gst_rtp_speex_depay_src_template);
-  ret = gst_pad_set_caps (GST_BASE_RTP_DEPAYLOAD_SRCPAD (depayload), srccaps);
+  rtpspeexdepay = GST_RTP_SPEEX_DEPAY (depayload);
 
-  gst_caps_unref (srccaps);
-  return ret;
+  structure = gst_caps_get_structure (caps, 0);
+
+  gst_structure_get_int (structure, "clock-rate", &clock_rate);
+  depayload->clock_rate = clock_rate;
+
+  if (!(params = gst_structure_get_string (structure, "encoding-params")))
+    nb_channels = 1;
+  else {
+    nb_channels = atoi (params);
+  }
+
+  /* construct minimal header and comment packet for the decoder */
+  buf = gst_buffer_new_and_alloc (80);
+  data = GST_BUFFER_DATA (buf);
+  memcpy (data, "Speex   ", 8);
+  data += 8;
+  memcpy (data, "1.1.12", 7);
+  data += 20;
+  GST_WRITE_UINT32_LE (data, 1);        /* version */
+  data += 4;
+  GST_WRITE_UINT32_LE (data, 80);       /* header_size */
+  data += 4;
+  GST_WRITE_UINT32_LE (data, clock_rate);       /* rate */
+  data += 4;
+  GST_WRITE_UINT32_LE (data, gst_rtp_speex_depay_get_mode (clock_rate));        /* mode */
+  data += 4;
+  GST_WRITE_UINT32_LE (data, 4);        /* mode_bitstream_version */
+  data += 4;
+  GST_WRITE_UINT32_LE (data, nb_channels);      /* nb_channels */
+  data += 4;
+  GST_WRITE_UINT32_LE (data, -1);       /* bitrate */
+  data += 4;
+  GST_WRITE_UINT32_LE (data, 0xa0);     /* frame_size */
+  data += 4;
+  GST_WRITE_UINT32_LE (data, 0);        /* VBR */
+  data += 4;
+  GST_WRITE_UINT32_LE (data, 1);        /* frames_per_packet */
+  data += 4;
+  GST_WRITE_UINT32_LE (data, 0);        /* extra_headers */
+  data += 4;
+  GST_WRITE_UINT32_LE (data, 0);        /* reserved1 */
+  data += 4;
+  GST_WRITE_UINT32_LE (data, 0);        /* reserved2 */
+
+  gst_base_rtp_depayload_push (GST_BASE_RTP_DEPAYLOAD (rtpspeexdepay), buf);
+
+  buf = gst_buffer_new_and_alloc (sizeof (gst_rtp_speex_comment));
+  memcpy (GST_BUFFER_DATA (buf), gst_rtp_speex_comment,
+      sizeof (gst_rtp_speex_comment));
+
+  gst_base_rtp_depayload_push (GST_BASE_RTP_DEPAYLOAD (rtpspeexdepay), buf);
+
+  return TRUE;
 }
 
 static GstBuffer *
 gst_rtp_speex_depay_process (GstBaseRTPDepayload * depayload, GstBuffer * buf)
 {
   GstBuffer *outbuf = NULL;
-  gint payload_len;
-  guint8 *payload;
 
   GST_DEBUG ("process : got %d bytes, mark %d ts %u seqn %d",
       GST_BUFFER_SIZE (buf),
       gst_rtp_buffer_get_marker (buf),
       gst_rtp_buffer_get_timestamp (buf), gst_rtp_buffer_get_seq (buf));
 
-  payload_len = gst_rtp_buffer_get_payload_len (buf);
-  payload = gst_rtp_buffer_get_payload (buf);
+  /* nothing special to be done */
+  outbuf = gst_rtp_buffer_get_payload_buffer (buf);
 
-  outbuf = gst_buffer_new_and_alloc (payload_len);
-  memcpy (GST_BUFFER_DATA (outbuf), payload, payload_len);
   return outbuf;
 }
 
@@ -139,5 +212,5 @@ gboolean
 gst_rtp_speex_depay_plugin_init (GstPlugin * plugin)
 {
   return gst_element_register (plugin, "rtpspeexdepay",
-      GST_RANK_NONE, GST_TYPE_RTP_SPEEX_DEPAY);
+      GST_RANK_MARGINAL, GST_TYPE_RTP_SPEEX_DEPAY);
 }
