@@ -31,28 +31,16 @@ GST_DEBUG_CATEGORY_STATIC (rtpvorbisdepay_debug);
 #define GST_CAT_DEFAULT (rtpvorbisdepay_debug)
 
 /* references:
- * http://svn.xiph.org/trunk/vorbis/doc/draft-ietf-avt-rtp-vorbis-04.txt
+ * http://www.rfc-editor.org/rfc/rfc5215.txt
  */
 
 /* elementfactory information */
 static const GstElementDetails gst_rtp_vorbis_depay_details =
 GST_ELEMENT_DETAILS ("RTP packet depayloader",
     "Codec/Depayloader/Network",
-    "Extracts Vorbis Audio from RTP packets (draft-04 of RFC XXXX)",
+    "Extracts Vorbis Audio from RTP packets (RFC 5215)",
     "Wim Taymans <wim@fluendo.com>");
 
-/* RtpVorbisDepay signals and args */
-enum
-{
-  /* FILL ME */
-  LAST_SIGNAL
-};
-
-enum
-{
-  ARG_0,
-};
-
 static GstStaticPadTemplate gst_rtp_vorbis_depay_sink_template =
 GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
@@ -64,13 +52,8 @@ GST_STATIC_PAD_TEMPLATE ("sink",
         /* All required parameters 
          *
          * "encoding-params = (string) <num channels>"
-         * "delivery-method = (string) { inline, in_band, out_band/<specific_name> } " 
          * "configuration = (string) ANY" 
          */
-        /* All optional parameters
-         *
-         * "configuration-uri =" 
-         */
     )
     );
 
@@ -89,10 +72,6 @@ static gboolean gst_rtp_vorbis_depay_setcaps (GstBaseRTPDepayload * depayload,
 static GstBuffer *gst_rtp_vorbis_depay_process (GstBaseRTPDepayload * depayload,
     GstBuffer * buf);
 
-static void gst_rtp_vorbis_depay_set_property (GObject * object, guint prop_id,
-    const GValue * value, GParamSpec * pspec);
-static void gst_rtp_vorbis_depay_get_property (GObject * object, guint prop_id,
-    GValue * value, GParamSpec * pspec);
 static void gst_rtp_vorbis_depay_finalize (GObject * object);
 
 static GstStateChangeReturn gst_rtp_vorbis_depay_change_state (GstElement *
@@ -123,8 +102,6 @@ gst_rtp_vorbis_depay_class_init (GstRtpVorbisDepayClass * klass)
   gstelement_class = (GstElementClass *) klass;
   gstbasertpdepayload_class = (GstBaseRTPDepayloadClass *) klass;
 
-  gobject_class->set_property = gst_rtp_vorbis_depay_set_property;
-  gobject_class->get_property = gst_rtp_vorbis_depay_get_property;
   gobject_class->finalize = gst_rtp_vorbis_depay_finalize;
 
   gstelement_class->change_state = gst_rtp_vorbis_depay_change_state;
@@ -348,7 +325,6 @@ gst_rtp_vorbis_depay_setcaps (GstBaseRTPDepayload * depayload, GstCaps * caps)
   GstStructure *structure;
   GstRtpVorbisDepay *rtpvorbisdepay;
   GstCaps *srccaps;
-  const gchar *delivery_method;
   const gchar *configuration;
   gint clock_rate;
 
@@ -360,28 +336,15 @@ gst_rtp_vorbis_depay_setcaps (GstBaseRTPDepayload * depayload, GstCaps * caps)
   if (!gst_structure_get_int (structure, "clock-rate", &clock_rate))
     goto no_rate;
 
-  /* see how the configuration parameters will be transmitted */
-  delivery_method = gst_structure_get_string (structure, "delivery-method");
-  if (delivery_method == NULL)
-    goto no_delivery_method;
-
-  if (g_strcasecmp (delivery_method, "inline")) {
-    /* configure string is in the caps */
-  } else if (g_strcasecmp (delivery_method, "in_band")) {
-    /* headers will (also) be transmitted in the RTP packets */
-  } else if (g_str_has_prefix (delivery_method, "out_band/")) {
-    /* some other method of header delivery. */
-    goto unsupported_delivery_method;
-  } else
-    goto unsupported_delivery_method;
-
   /* read and parse configuration string */
   configuration = gst_structure_get_string (structure, "configuration");
-  if (configuration == NULL)
-    goto no_configuration;
-
-  if (!gst_rtp_vorbis_depay_parse_configuration (rtpvorbisdepay, configuration))
-    goto invalid_configuration;
+  if (configuration) {
+    if (!gst_rtp_vorbis_depay_parse_configuration (rtpvorbisdepay,
+            configuration))
+      goto invalid_configuration;
+  } else {
+    GST_WARNING_OBJECT (rtpvorbisdepay, "no configuration specified");
+  }
 
   /* caps seem good, configure element */
   depayload->clock_rate = clock_rate;
@@ -394,22 +357,6 @@ gst_rtp_vorbis_depay_setcaps (GstBaseRTPDepayload * depayload, GstCaps * caps)
   return TRUE;
 
   /* ERRORS */
-unsupported_delivery_method:
-  {
-    GST_ERROR_OBJECT (rtpvorbisdepay,
-        "unsupported delivery-method \"%s\" specified", delivery_method);
-    return FALSE;
-  }
-no_delivery_method:
-  {
-    GST_ERROR_OBJECT (rtpvorbisdepay, "no delivery-method specified");
-    return FALSE;
-  }
-no_configuration:
-  {
-    GST_ERROR_OBJECT (rtpvorbisdepay, "no configuration specified");
-    return FALSE;
-  }
 invalid_configuration:
   {
     GST_ERROR_OBJECT (rtpvorbisdepay, "invalid configuration specified");
@@ -654,7 +601,7 @@ bad_packet:
   }
 switch_failed:
   {
-    GST_ELEMENT_ERROR (rtpvorbisdepay, STREAM, DECODE,
+    GST_ELEMENT_WARNING (rtpvorbisdepay, STREAM, DECODE,
         (NULL), ("Could not switch codebooks"));
     return NULL;
   }
@@ -677,36 +624,6 @@ length_short:
   }
 }
 
-static void
-gst_rtp_vorbis_depay_set_property (GObject * object, guint prop_id,
-    const GValue * value, GParamSpec * pspec)
-{
-  GstRtpVorbisDepay *rtpvorbisdepay;
-
-  rtpvorbisdepay = GST_RTP_VORBIS_DEPAY (object);
-
-  switch (prop_id) {
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-      break;
-  }
-}
-
-static void
-gst_rtp_vorbis_depay_get_property (GObject * object, guint prop_id,
-    GValue * value, GParamSpec * pspec)
-{
-  GstRtpVorbisDepay *rtpvorbisdepay;
-
-  rtpvorbisdepay = GST_RTP_VORBIS_DEPAY (object);
-
-  switch (prop_id) {
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-      break;
-  }
-}
-
 static GstStateChangeReturn
 gst_rtp_vorbis_depay_change_state (GstElement * element,
     GstStateChange transition)
